@@ -1,8 +1,9 @@
-from . import video, user, dynamic, bangumi, live, article, exceptions, tools, audio, channel
+from . import video, user, dynamic, bangumi, live, article, exceptions, tools, audio, channel, utils
 from .utils import aid2bvid, bvid2aid, upload_image, Verify, Danmaku, Color, request_settings
+from .common import get_vote_info
 
 META = {
-    "version": "2.0.0"
+    "version": "2.0.3"
 }
 
 
